@@ -25,11 +25,20 @@ def create_directory_if_not_exists(path, level=logging.DEBUG):
         logger.debug(path, " does not exist, creating ...")
         os.makedirs(path) 
 
-def get_cache_directory():
+def get_cache_directory(level=logging.DEBUG):
+    logger = logging.getLogger("logger")
+    logger.setLevel(level)
+    logger.addHandler(logging.StreamHandler())
+
     if platform.system().lower() == "windows":
         return os.path.expandvars(%localappdata%)
-    else:
+    elif platform.system().lower() == "linux":
         return "~/.cache"
+    elif platform.system().lower() == "darwin":
+        return "~/Library/"
+    
+    logger.error("Could not determine platform")
+    return ""
 
 def get_git_directory(level=logging.DEBUG):
     logger = logging.getLogger("logger")
